# aio-videoindexer
[![Documentation Status](https://readthedocs.org/projects/aio-videoindexer/badge/?version=latest)](https://aio-videoindexer.readthedocs.io/en/latest/?badge=latest) ![PyPI](https://img.shields.io/pypi/v/aio-videoindexer) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/aio-videoindexer) [![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/) ![GitHub issues](https://img.shields.io/github/issues/Sealjay-clj/aio-videoindexer) ![GitHub](https://img.shields.io/github/license/Sealjay-clj/aio-videoindexer)  ![I Love Badges](https://img.shields.io/badge/-I%20Love%20Badges-blueviolet) ![GitHub Repo stars](https://img.shields.io/github/stars/Sealjay-clj/aio-videoindexer?style=social)

## Overview
An async video indexer package for querying [Microsoft Media Services Video Indexer](https://docs.microsoft.com/en-us/azure/media-services/video-indexer/) in Python.

aio-videoindexer is available under the [MIT Licence](./LICENCE).
## Installation

The package can be found on [PyPy](https://pypi.org/project/aio-videoindexer/) and can be installed using pip.

   ```bash
   $ pip install aio-videoindexer
   ```

## Documentation

For more information including usage examples, see [https://aio-videoindexer.readthedocs.io/en/latest/](https://aio-videoindexer.readthedocs.io/en/latest/).

## Contact
Feel free to contact me [on Twitter](https://twitter.com/sealjay_clj). For bugs, please [raise an issue on GitHub](https://github.com/Sealjay-clj/aio-videoindexer/issues).
## Background
This library is forked from a [Teams Vid](https://github.com/sealjay-clj/teams-vid) project, designed to use video to connect people during the pandemic.

## Contributing
Contributions are more than welcome.
- Create a fork.
- Create a feature branch `git checkout -b feature/featurename` in the [Gitflow style](https://www.atlassian.com/git/tutorials/comparing-workflows/gitflow-workflow).
- Commit your changes `git commit -am 'Bug: Fixed a bug'` using [semantic commits](https://nitayneeman.com/posts/understanding-semantic-commit-messages-using-git-and-angular/#common-types).
- Push to the branch `git push`.
- Create a new [pull request](https://docs.github.com/en/desktop/contributing-and-collaborating-using-github-desktop/creating-an-issue-or-pull-request) for review when ready, relating to [the issue](https://guides.github.com/features/issues/).
